@@ -1,3 +1,26 @@
+"""
+## Amazon Route53 Resolver Construct Library
+
+<html></html>---
+
+
+![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
+
+> **This is a *developer preview* (public beta) module. Releases might lack important features and might have
+> future breaking changes.**
+>
+> This API is still under active development and subject to non-backward
+> compatible changes or removal in any future version. Use of the API is not recommended in production
+> environments. Experimental APIs are not subject to the Semantic Versioning model.
+
+---
+<html></html>
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+route53resolver = require("@aws-cdk/aws-route53resolver")
+```
+"""
 import abc
 import datetime
 import enum
@@ -10,7 +33,8 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53resolver", "1.7.0", __name__, "aws-route53resolver@1.7.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53resolver", "1.16.0", __name__, "aws-route53resolver@1.16.0.jsii.tgz")
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnResolverEndpoint(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-route53resolver.CfnResolverEndpoint"):
     """A CloudFormation ``AWS::Route53Resolver::ResolverEndpoint``.
 
@@ -35,6 +59,17 @@ class CfnResolverEndpoint(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
         jsii.create(CfnResolverEndpoint, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -294,6 +329,7 @@ class CfnResolverEndpointProps():
         return 'CfnResolverEndpointProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnResolverRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-route53resolver.CfnResolverRule"):
     """A CloudFormation ``AWS::Route53Resolver::ResolverRule``.
 
@@ -319,6 +355,17 @@ class CfnResolverRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
 
         jsii.create(CfnResolverRule, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -515,6 +562,7 @@ class CfnResolverRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
 
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnResolverRuleAssociation(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-route53resolver.CfnResolverRuleAssociation"):
     """A CloudFormation ``AWS::Route53Resolver::ResolverRuleAssociation``.
 
@@ -537,6 +585,17 @@ class CfnResolverRuleAssociation(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMe
 
         jsii.create(CfnResolverRuleAssociation, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
